@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import re
+import uuid
 
 from urllib.parse import urlparse, urlencode, quote
 
@@ -16,8 +17,14 @@ def _account_action(app, user, account, action):
     return http.post(app, user, url).json()
 
 
-def create_app(domain):
-    url = 'https://{}/api/v1/apps'.format(domain)
+def _status_action(app, user, status_id, action):
+    url = '/api/v1/statuses/{}/{}'.format(status_id, action)
+
+    return http.post(app, user, url).json()
+
+
+def create_app(domain, scheme='https'):
+    url = '{}://{}/api/v1/apps'.format(scheme, domain)
 
     data = {
         'client_name': CLIENT_NAME,
@@ -76,15 +83,65 @@ def request_access_token(app, authorization_code):
     return http.process_response(response).json()
 
 
-def post_status(app, user, status, visibility='public', media_ids=None,
-                sensitive=False, spoiler_text=None):
+def post_status(
+    app,
+    user,
+    status,
+    visibility='public',
+    media_ids=None,
+    sensitive=False,
+    spoiler_text=None,
+    in_reply_to_id=None
+):
+    """
+    Posts a new status.
+    https://github.com/tootsuite/documentation/blob/master/Using-the-API/API.md#posting-a-new-status
+    """
+
+    # Idempotency key assures the same status is not posted multiple times
+    # if the request is retried.
+    headers = {"Idempotency-Key": uuid.uuid4().hex}
+
     return http.post(app, user, '/api/v1/statuses', {
         'status': status,
         'media_ids[]': media_ids,
         'visibility': visibility,
-        'sensitive': sensitive,
+        'sensitive': "true" if sensitive else "false",
         'spoiler_text': spoiler_text,
-    }).json()
+        'in_reply_to_id': in_reply_to_id,
+    }, headers=headers).json()
+
+
+def delete_status(app, user, status_id):
+    """
+    Deletes a status with given ID.
+    https://github.com/tootsuite/documentation/blob/master/Using-the-API/API.md#deleting-a-status
+    """
+    return http.delete(app, user, '/api/v1/statuses/{}'.format(status_id))
+
+
+def favourite(app, user, status_id):
+    return _status_action(app, user, status_id, 'favourite')
+
+
+def unfavourite(app, user, status_id):
+    return _status_action(app, user, status_id, 'unfavourite')
+
+
+def reblog(app, user, status_id):
+    return _status_action(app, user, status_id, 'reblog')
+
+
+def unreblog(app, user, status_id):
+    return _status_action(app, user, status_id, 'unreblog')
+
+
+def pin(app, user, status_id):
+    return _status_action(app, user, status_id, 'pin')
+
+
+def unpin(app, user, status_id):
+    return _status_action(app, user, status_id, 'unpin')
 
 
 def timeline_home(app, user):
@@ -192,6 +249,6 @@ def get_notifications(app, user):
     return http.get(app, user, '/api/v1/notifications').json()
 
 
-def get_instance(domain):
-    url = "http://{}/api/v1/instance".format(domain)
+def get_instance(domain, scheme="https"):
+    url = "{}://{}/api/v1/instance".format(scheme, domain)
     return http.anon_get(url).json()
