@@ -4,7 +4,7 @@ from toot import api, config
 from toot.auth import login_interactive, login_browser_interactive, create_app_interactive
 from toot.exceptions import ConsoleError, NotFoundError
 from toot.output import print_out, print_instance, print_account, print_search_results, print_timeline
-from toot.utils import assert_domain_exists
+from toot.utils import assert_domain_exists, multiline_input, EOF_KEY
 
 
 def timeline(app, user, args):
@@ -24,6 +24,9 @@ def timeline(app, user, args):
     else:
         items = api.timeline_home(app, user)
 
+    if args.reverse:
+        items = reversed(items)
+
     print_timeline(items)
 
 
@@ -53,6 +56,10 @@ def post(app, user, args):
     if media and not args.text:
         args.text = media['text_url']
 
+    if not args.text:
+        print_out("Write or paste your toot. Press <yellow>{}</yellow> to post it.".format(EOF_KEY))
+        args.text = multiline_input()
+
     if not args.text:
         raise ConsoleError("You must specify either text or media to post.")
 
@@ -62,11 +69,47 @@ def post(app, user, args):
         media_ids=media_ids,
         sensitive=args.sensitive,
         spoiler_text=args.spoiler_text,
+        in_reply_to_id=args.reply_to,
     )
 
     print_out("Toot posted: <green>{}</green>".format(response.get('url')))
 
 
+def delete(app, user, args):
+    api.delete_status(app, user, args.status_id)
+    print_out("<green>✓ Status deleted</green>")
+
+
+def favourite(app, user, args):
+    api.favourite(app, user, args.status_id)
+    print_out("<green>✓ Status favourited</green>")
+
+
+def unfavourite(app, user, args):
+    api.unfavourite(app, user, args.status_id)
+    print_out("<green>✓ Status unfavourited</green>")
+
+
+def reblog(app, user, args):
+    api.reblog(app, user, args.status_id)
+    print_out("<green>✓ Status reblogged</green>")
+
+
+def unreblog(app, user, args):
+    api.unreblog(app, user, args.status_id)
+    print_out("<green>✓ Status unreblogged</green>")
+
+
+def pin(app, user, args):
+    api.pin(app, user, args.status_id)
+    print_out("<green>✓ Status pinned</green>")
+
+
+def unpin(app, user, args):
+    api.unpin(app, user, args.status_id)
+    print_out("<green>✓ Status unpinned</green>")
+
+
 def auth(app, user, args):
     config_data = config.load_config()
 
@@ -85,16 +128,16 @@ def auth(app, user, args):
     print_out("\nAuth tokens are stored in: <blue>{}</blue>".format(path))
 
 
-def login(app, user, args):
-    app = create_app_interactive(instance=args.instance)
+def login_cli(app, user, args):
+    app = create_app_interactive(instance=args.instance, scheme=args.scheme)
     login_interactive(app, args.email)
 
     print_out()
     print_out("<green>✓ Successfully logged in.</green>")
 
 
-def login_browser(app, user, args):
-    app = create_app_interactive(instance=args.instance)
+def login(app, user, args):
+    app = create_app_interactive(instance=args.instance, scheme=args.scheme)
     login_browser_interactive(app)
 
     print_out()
@@ -209,7 +252,7 @@ def instance(app, user, args):
     assert_domain_exists(name)
 
     try:
-        instance = api.get_instance(name)
+        instance = api.get_instance(name, args.scheme)
         print_instance(instance)
     except NotFoundError:
         raise ConsoleError(
