@@ -24,17 +24,30 @@ def visibility(value):
 Command = namedtuple("Command", ["name", "description", "require_auth", "arguments"])
 
 
+# Aruguments added to every command
 common_args = [
     (["--no-color"], {
         "help": "don't use ANSI colors in output",
         "action": 'store_true',
         "default": False,
     }),
+    (["--quiet"], {
+        "help": "don't write to stdout on success",
+        "action": 'store_true',
+        "default": False,
+    }),
     (["--debug"], {
         "help": "show debug log in console",
         "action": 'store_true',
         "default": False,
-    })
+    }),
+]
+
+# Arguments added to commands which require authentication
+common_auth_args = [
+    (["-u", "--using"], {
+        "help": "the account to use, overrides active account",
+    }),
 ]
 
 account_arg = (["account"], {
@@ -51,18 +64,30 @@ email_arg = (["-e", "--email"], {
     "help": 'email address to log in with',
 })
 
+scheme_arg = (["--disable-https"], {
+    "help": "disable HTTPS and use insecure HTTP",
+    "dest": "scheme",
+    "default": "https",
+    "action": "store_const",
+    "const": "http",
+})
+
+status_id_arg = (["status_id"], {
+    "help": "ID of the status",
+    "type": int,
+})
 
 AUTH_COMMANDS = [
     Command(
         name="login",
-        description="Log in from the console, does NOT support two factor authentication",
-        arguments=[instance_arg, email_arg],
+        description="Log into a mastodon instance using your browser (recommended)",
+        arguments=[instance_arg, scheme_arg],
         require_auth=False,
     ),
     Command(
-        name="login_browser",
-        description="Log in using your browser, supports regular and two factor authentication",
-        arguments=[instance_arg],
+        name="login_cli",
+        description="Log in from the console, does NOT support two factor authentication",
+        arguments=[instance_arg, email_arg, scheme_arg],
         require_auth=False,
     ),
     Command(
@@ -110,7 +135,7 @@ READ_COMMANDS = [
                 "help": "instance domain (e.g. 'mastodon.social') or blank to use current",
                 "nargs": "?",
             }),
-
+            scheme_arg,
         ],
         require_auth=False,
     ),
@@ -151,6 +176,11 @@ READ_COMMANDS = [
                 "default": False,
                 "help": "Show only statuses from local instance (public and tag timelines only).",
             }),
+            (["-r", "--reverse"], {
+                "action": "store_true",
+                "default": False,
+                "help": "Reverse the order of the shown timeline (to new posts at the bottom)",
+            }),
         ],
         require_auth=True,
     ),
@@ -198,7 +228,11 @@ POST_COMMANDS = [
             (["-p", "--spoiler-text"], {
                 "type": str,
                 "help": 'text to be shown as a warning before the actual content',
-            })
+            }),
+            (["-r", "--reply-to"], {
+                "type": int,
+                "help": 'local ID of the status you want to reply to',
+            }),
         ],
         require_auth=True,
     ),
@@ -215,6 +249,51 @@ POST_COMMANDS = [
     ),
 ]
 
+STATUS_COMMANDS = [
+    Command(
+        name="delete",
+        description="Delete a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="favourite",
+        description="Favourite a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="unfavourite",
+        description="Unfavourite a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="reblog",
+        description="Reblog a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="unreblog",
+        description="Unreblog a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="pin",
+        description="Pin a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="unpin",
+        description="Unpin a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+]
+
 ACCOUNTS_COMMANDS = [
     Command(
         name="follow",
@@ -266,7 +345,7 @@ ACCOUNTS_COMMANDS = [
     ),
 ]
 
-COMMANDS = AUTH_COMMANDS + READ_COMMANDS + POST_COMMANDS + ACCOUNTS_COMMANDS
+COMMANDS = AUTH_COMMANDS + READ_COMMANDS + POST_COMMANDS + STATUS_COMMANDS + ACCOUNTS_COMMANDS
 
 
 def print_usage():
@@ -276,6 +355,7 @@ def print_usage():
         ("Authentication", AUTH_COMMANDS),
         ("Read", READ_COMMANDS),
         ("Post", POST_COMMANDS),
+        ("Status", STATUS_COMMANDS),
         ("Accounts", ACCOUNTS_COMMANDS),
     ]
 
@@ -303,12 +383,12 @@ def get_argument_parser(name, command):
         description=command.description,
         epilog=CLIENT_WEBSITE)
 
-    for args, kwargs in command.arguments + common_args:
-        parser.add_argument(*args, **kwargs)
-
-    # If the command requires auth, give an option to select account
+    combined_args = command.arguments + common_args
     if command.require_auth:
-        parser.add_argument("-u", "--using", help="the account to use, overrides active account")
+        combined_args += common_auth_args
+
+    for args, kwargs in combined_args:
+        parser.add_argument(*args, **kwargs)
 
     return parser
 
@@ -365,9 +445,8 @@ def main():
 
     try:
         run_command(app, user, command_name, args)
-    except ConsoleError as e:
-        print_err(str(e))
-        sys.exit(1)
-    except ApiError as e:
+    except (ConsoleError, ApiError) as e:
         print_err(str(e))
         sys.exit(1)
+    except KeyboardInterrupt as e:
+        pass
